# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class StickerSet(Object):
    """
    Args:
        id: ``int``
        access_hash: ``int``
        title: ``string``
        short_name: ``string``
        count: ``int``
        hash: ``int``
        installed: ``bool`` (optional)
        archived: ``bool`` (optional)
        official: ``bool`` (optional)
        masks: ``bool`` (optional)
    """
    ID = 0xcd303b41

    def __init__(self, id, access_hash, title, short_name, count, hash, installed=None, archived=None, official=None, masks=None, **kwargs):
        self.installed = installed  # flags.0?true
        self.archived = archived  # flags.1?true
        self.official = official  # flags.2?true
        self.masks = masks  # flags.3?true
        self.id = id  # long
        self.access_hash = access_hash  # long
        self.title = title  # string
        self.short_name = short_name  # string
        self.count = count  # int
        self.hash = hash  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "StickerSet":
        flags = Int.read(b)
        
        installed = True if flags & (1 << 0) else False
        archived = True if flags & (1 << 1) else False
        official = True if flags & (1 << 2) else False
        masks = True if flags & (1 << 3) else False
        id = Long.read(b)
        
        access_hash = Long.read(b)
        
        title = String.read(b)
        
        short_name = String.read(b)
        
        count = Int.read(b)
        
        hash = Int.read(b)
        
        return StickerSet(id, access_hash, title, short_name, count, hash, installed, archived, official, masks)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.installed is not None else 0
        flags |= (1 << 1) if self.archived is not None else 0
        flags |= (1 << 2) if self.official is not None else 0
        flags |= (1 << 3) if self.masks is not None else 0
        b.write(Int(flags))
        
        b.write(Long(self.id))
        
        b.write(Long(self.access_hash))
        
        b.write(String(self.title))
        
        b.write(String(self.short_name))
        
        b.write(Int(self.count))
        
        b.write(Int(self.hash))
        
        return b.getvalue()
